package com.bensleys.audiostreamer;

import android.app.Activity;
import android.app.AlertDialog;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.database.Cursor;
import android.media.AudioManager;
import android.net.ConnectivityManager;
import android.net.NetworkInfo;
import android.os.Bundle;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.Button;
import android.widget.GridView;
import android.widget.TextView;
import android.widget.Toast;

public class AudioStreamer extends Activity  {
	
	// Interface variables
	TextView LBL_DURATION;
	static TextView TXT_DURATION;
	TextView LBL_STATION;
	static TextView TXT_STATION;
	static Button BTN_LISTEN;
	GridView gridview;
	
	Integer intREQUEST = 1;
	
	// DB and data variables:
	SQLite CLS_SQL_LITE = new SQLite(this);
	public Long LNG_ST_ID[] = new Long[6];
	public String STR_ST_NAME[] = new String[6];
	public String STR_ST_URL[] = new String[6];
	public Integer INT_ST_LISTENS[] = new Integer[6];
	
	@Override
    public void onCreate(Bundle savedInstanceState) {
    	
    	// Interface and layout set up bobbins:
        super.onCreate(savedInstanceState);
        setContentView(R.layout.main);
        
        LBL_DURATION = (TextView)this.findViewById(R.id.lblDuration);
        TXT_DURATION = (TextView)this.findViewById(R.id.txtDuration);
        LBL_STATION = (TextView)this.findViewById(R.id.lblStation);
        TXT_STATION = (TextView)this.findViewById(R.id.txtStation);
        BTN_LISTEN = (Button)this.findViewById(R.id.btnListen);
        
        BTN_LISTEN.setOnClickListener(new Button.OnClickListener() {public void onClick(View v) {play();} });
        
        gridview = (GridView) findViewById(R.id.gridview);
        
        RefreshInterface();
        
        // Lock the context of the volume buttons
        setVolumeControlStream(AudioManager.STREAM_MUSIC);
        
        if(StreamService.INT_PLAY_STATE==1){
    		BTN_LISTEN.setText(R.string.strStop);
    		TXT_STATION.setText(GlobalVars.STR_STATION);
        }

    }
	
	protected void onActivityResult(int requestCode, int resultCode, Intent data){
		RefreshInterface();
	}
	
	public void RefreshInterface() {
        // SQL initial set up:
        // Lets open the DB and as defined in the DB class by getWritableDatabase()
        // if its empty some initial values will be entered so we start the app by grabbing stored entries
        // (which for this app, would be stored stations), even if they are just the defaults
		CLS_SQL_LITE.open();
        Cursor c = CLS_SQL_LITE.getAllStations();  
        if (c.getCount() > 0) { //This query is wrapped in an IF statement, just in case there was something wrong with the SQL creation/execution
        	Integer i = 0;
         	c.moveToFirst();
			while(i < c.getCount()){
				LNG_ST_ID[i] = c.getLong(0);
				STR_ST_NAME[i] = c.getString(1);
				STR_ST_URL[i] = c.getString(2);
				INT_ST_LISTENS[i] = 0;
				i++;
				c.moveToNext();
        	}
		c.close();
        }else{
        	Toast.makeText(this, "There was an error reading the stations DB! :(", Toast.LENGTH_LONG).show();
        }
        CLS_SQL_LITE.close();
        gridview.setAdapter(new GridAdapter(this));
	}
    
	// A customer adapter class to fill the GridView with buttons that set the station
    public class GridAdapter extends BaseAdapter {

    	private Context context;

    	public GridAdapter(Context context) {
    	    this.context = context;
    	}

    	public int getCount() {
    	    return STR_ST_NAME.length;
    	}

    	public Object getItem(int position) {
    	    return null;
    	}

    	public long getItemId(int position) {
    	    return 0;
    	}

    	@Override
    	public View getView(final int position, View convertView, ViewGroup parent) {
    		Button gridBtn;
    		
    	    if (convertView == null) {
    	    	gridBtn = new Button(context);
    	    	gridBtn.setLayoutParams(new GridView.LayoutParams(80, 80));
    	    }
    	    else {
    	    	gridBtn = (Button) convertView;
    	    }

    	    gridBtn.setText(STR_ST_NAME[position]);
    	    gridBtn.setOnClickListener(new Button.OnClickListener() {public void onClick(View v) {changeto(position);} });
    	    gridBtn.setOnLongClickListener(new Button.OnLongClickListener() {public boolean onLongClick(View v) {edit(position); return true;} });
    	    return gridBtn;
    	}

    }
    
    public void changeto(Integer sid){
    	if(StreamService.INT_PLAY_STATE==1){ // If we are currently playing a station, stop it
    		play();
    	}
    	if(STR_ST_URL[sid]!=""){ // Make sure a valid station has been chosen and not a blank button
    		GlobalVars.STR_STATION = STR_ST_NAME[sid];
    		GlobalVars.STR_URL = STR_ST_URL[sid];
    		play();
    	}
    }
    
    public void edit(Integer sid){ // Method to edit a station entry,
    	if(LNG_ST_ID[sid]==null){ // If this station button has no station ID assigned to it its a blank button
    		GlobalVars.BOL_NEW_ST = true; // and so a new station <<
    		
    	}else{
    		GlobalVars.BOL_NEW_ST = false; // else its an existing station,
    		GlobalVars.INT_EDIT_ID = LNG_ST_ID[sid].longValue(); // Parse its station ID
    	}
    	Intent intent = new Intent(AudioStreamer.this, EditStation.class); // Start a new intent to launch the editor activity
        startActivityForResult(intent, intREQUEST); // (Which is launched as an activity for result, because when the result comes back
        // we call the RefreshInterface() method to update the buttons)
    }
 	  	
    public void play() {
    	if(StreamService.INT_PLAY_STATE==1){ // If the stream service is currently running
    		stopService(new Intent(this, StreamService.class)); // Stop the streaming service
    	}else if(StreamService.INT_PLAY_STATE==0){ // Else, we want to start a stream
    		if(GlobalVars.STR_URL!="" && GlobalVars.STR_URL!=null){
    			if(isOnline()){ // Check we actually have network connectivity
    				listen();
    			}else{ 
    			// If no network connection was found it could just be a miss-match between the code and device
    			// so prompt the user, 'yes' or 'no' in case they DO have connectivity
    				AlertDialog.Builder connectionAlertBuilder = new AlertDialog.Builder(this); //An AlertDialog builder has been created for to handle the dialog response
    	        	connectionAlertBuilder.setMessage("No network connection has been detected on this device, are you sure you want to try and listen?");
    	        	connectionAlertBuilder.setPositiveButton("Yes", diConnectivity);
    	        	connectionAlertBuilder.setNegativeButton("No", diConnectivity);
    	        	connectionAlertBuilder.show();
    			}
    		}else{
    			Toast.makeText(this, "No station selected", Toast.LENGTH_SHORT).show(); // Probably because a blank button was pressed, dummy!
    		}
    	}
    }
    
    DialogInterface.OnClickListener diConnectivity = new DialogInterface.OnClickListener() {
        @Override
        public void onClick(DialogInterface dialog, int which) {
            if(which==DialogInterface.BUTTON_POSITIVE){ // "Yes" button clicked...
            	listen(); // Call the listen method
            }
        }
    };
    
    public void listen(){
    	startService(new Intent(this, StreamService.class)); // Start the streaming service
    }
    
	public boolean isOnline() { // Method to check if a network connection is detected, returns true if so;
		ConnectivityManager connectivityManager = (ConnectivityManager)getApplicationContext().getSystemService(Context.CONNECTIVITY_SERVICE);
		NetworkInfo networkInfo = connectivityManager.getActiveNetworkInfo();
		boolean connected = networkInfo != null && networkInfo.isAvailable() && networkInfo.isConnected();
		return connected;
	}
}