package com.bensleys.audiostreamer;

import android.app.Activity;
import android.content.ContentValues;
import android.content.Intent;
import android.database.Cursor;
import android.media.AudioManager;
import android.os.Bundle;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.TextView;
import android.widget.Toast;

public class EditStation extends Activity  {
	
	EditText TXT_NAME;
	EditText TXT_URL;
	TextView TXT_LISTENS;
	
	// Create an interface to the custom SQLLite class
	SQLite CLS_SQL_LITE = new SQLite(this);
	
	@Override
 	public void onCreate(Bundle savedInstanceState) {
 		super.onCreate(savedInstanceState);
    	setContentView(R.layout.edit);
    	
    	// Interface and layout variables and objects
    	TXT_NAME = (EditText)this.findViewById(R.id.txtName);
    	TXT_URL = (EditText)this.findViewById(R.id.txtURL);
    	TXT_LISTENS = (TextView)this.findViewById(R.id.txtListens);
    	
    	Button BTN_CANCEL = (Button)this.findViewById(R.id.btnCancel);
    	Button BTN_SAVE = (Button)this.findViewById(R.id.btnSave);
    	Button BTN_DELETE = (Button)this.findViewById(R.id.btnDelete);
    	
    	// Assign onClickListeners to the onClick events of each button, each of which is assigned itself to a function
    	BTN_CANCEL.setOnClickListener(new Button.OnClickListener() {public void onClick(View v) { end();} });
        BTN_SAVE.setOnClickListener(new Button.OnClickListener() {public void onClick(View v) {save();} });
        BTN_DELETE.setOnClickListener(new Button.OnClickListener() {public void onClick(View v) {delete();} });
      
        // Lock the context of the volume buttons
        setVolumeControlStream(AudioManager.STREAM_MUSIC);
        
        // Has this screen be called to edit an existing station or enter a new one?
        if(GlobalVars.BOL_NEW_ST==false){
        	// Edit an existing one..
        	CLS_SQL_LITE.open();
        	// Query for the existing station by its DB ID
        	Cursor c = CLS_SQL_LITE.db.query(true, GlobalVars.DB_TABLE, new String[] {
        			"id", "name", "url", "listens", "duration"}, 
            		"id" + "=" + GlobalVars.INT_EDIT_ID, null, null, null, null, null);
        	// Where any rows returned?
        	if (c.getCount() > 0) {
        		c.moveToFirst();
				TXT_NAME.setText(c.getString(1));
				TXT_URL.setText(c.getString(2));
				TXT_LISTENS.setText(c.getString(3));
			// If not that means something probably went wrong as only valid stations IDs should be passed here
        	}else{
	        	Toast.makeText(this, "There was an error getting the station information", Toast.LENGTH_SHORT).show();
        	}
        	c.close();
        	CLS_SQL_LITE.close();
        }
        
    }
	
	public void save(){
		ContentValues args = new ContentValues();
	     args.put("name", TXT_NAME.getText().toString());
	     args.put("url", TXT_URL.getText().toString());
	     args.put("listens", 0);
	     args.put("duration", 0);
		CLS_SQL_LITE.open();
		// Make sure were aren't pressing the save button to update a station 
		// that has never been saved before, and thusly isn't in the DB
		if(GlobalVars.BOL_NEW_ST==false){
		    Integer result =CLS_SQL_LITE.db.update(GlobalVars.DB_TABLE, args, "id" + "=" + GlobalVars.INT_EDIT_ID, null);
			if(result!=1){ // The number of rows update is returned, seeing as we edit stations one at a time this should always be 1
	        	Toast.makeText(this, "There was an error updating the station", Toast.LENGTH_SHORT).show();
	        }
		// If this isn't a station that has been saved before, it must be a new one so rather
		// than trying and update it by its non-existing DB ID, save this station as a new entry
		}else{
			long result = CLS_SQL_LITE.db.insert(GlobalVars.DB_TABLE, null, args);
			if(result<0){ // The row ID of the new row is returned so, less than zero indicates an error
	        	Toast.makeText(this, "There was an error saving the station", Toast.LENGTH_SHORT).show();
	        }
		}
		CLS_SQL_LITE.close();
        end();
        
	}
	
	public void delete(){
		CLS_SQL_LITE.open();
		// Make sure were aren't pressing the delete button on a station 
		// that has never been saved before, and thusly isn't in the DB
		if(GlobalVars.BOL_NEW_ST==false){
			// Delete this station by its ID
			Integer result = CLS_SQL_LITE.db.delete(GlobalVars.DB_TABLE, "id" + "=" + GlobalVars.INT_EDIT_ID, null);
			if(result<1){
				Toast.makeText(this, "There was an error deleting the station", Toast.LENGTH_SHORT).show();
			}
		}
		CLS_SQL_LITE.close();
		end();
	}
	
	public void end(){ // This method is for ending this activity,
		// returning to the main UI thread, and telling it through
		// an activity result that control has been return so it knows
		// to updates its UI by re-querying the DB for potential changes
		Intent returnIntent = new Intent();
        returnIntent.putExtra("value", "one");
        setResult(RESULT_OK,returnIntent);
        finish();
	}
  
}

